==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24JarURLResource.h <==
// final class java.net.URLClassLoader$JarURLResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 90b15cc913c0b6fe java_net_URLClassLoader__24JarURLResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24JarURLResource_H_
#define _JC_java_net_URLClassLoader__24JarURLResource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24JarURLLoader$object;
struct _jc_java_util_jar_JarEntry$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$sub_refs	_jc_java_net_URLClassLoader__24JarURLResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs	_jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$refs	_jc_java_net_URLClassLoader__24JarURLResource$refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$nonrefs	_jc_java_net_URLClassLoader__24JarURLResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$object	_jc_java_net_URLClassLoader__24JarURLResource$object;

typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vmethods	_jc_java_net_URLClassLoader__24JarURLResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vtable	_jc_java_net_URLClassLoader__24JarURLResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vtype	_jc_java_net_URLClassLoader__24JarURLResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24JarURLResource$method$_init$90053d0c2a71fa4c(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_jar_JarEntry$object *);

// Virtual methods
extern _jc_object_array *_jc_java_net_URLClassLoader__24JarURLResource$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24JarURLResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
extern jint _jc_java_net_URLClassLoader__24JarURLResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24JarURLResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24JarURLResource$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24JarURLResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24JarURLResource$vmethods	java_net_URLClassLoader__24JarURLResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24JarURLResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24JarURLResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLResource$sub_refs {
	struct _jc_java_util_jar_JarEntry$object	*entry;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLResource$refs {
    _jc_java_net_URLClassLoader__24JarURLResource$sub_refs	java_net_URLClassLoader__24JarURLResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs	java_net_URLClassLoader__24JarURLResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24JarURLResource$object {
	_jc_java_net_URLClassLoader__24JarURLResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24JarURLResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24JarURLResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24JarURLResource$vtype _jc_java_net_URLClassLoader__24JarURLResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24JarURLResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24JarURLResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24JarURLResource_H_ */

==> jc-1.4.6.tar.gz: java/net/URLClassLoader__24JarURLResource.h <==
// final class java.net.URLClassLoader$JarURLResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 90b15cc913c0b6fe java_net_URLClassLoader__24JarURLResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24JarURLResource_H_
#define _JC_java_net_URLClassLoader__24JarURLResource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24JarURLLoader$object;
struct _jc_java_util_jar_JarEntry$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$sub_refs	_jc_java_net_URLClassLoader__24JarURLResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs	_jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$refs	_jc_java_net_URLClassLoader__24JarURLResource$refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$nonrefs	_jc_java_net_URLClassLoader__24JarURLResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLResource$object	_jc_java_net_URLClassLoader__24JarURLResource$object;

typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vmethods	_jc_java_net_URLClassLoader__24JarURLResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vtable	_jc_java_net_URLClassLoader__24JarURLResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24JarURLResource$vtype	_jc_java_net_URLClassLoader__24JarURLResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24JarURLResource$method$_init$90053d0c2a71fa4c(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_net_URLClassLoader__24JarURLResource$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24JarURLResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_URLClassLoader__24JarURLResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24JarURLResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24JarURLResource$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLResource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24JarURLResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24JarURLResource$vmethods	java_net_URLClassLoader__24JarURLResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24JarURLResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24JarURLResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLResource$sub_refs {
	struct _jc_java_util_jar_JarEntry$object	*entry;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLResource$refs {
    _jc_java_net_URLClassLoader__24JarURLResource$sub_refs	java_net_URLClassLoader__24JarURLResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24JarURLResource$sub_nonrefs	java_net_URLClassLoader__24JarURLResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24JarURLResource$object {
	_jc_java_net_URLClassLoader__24JarURLResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24JarURLResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24JarURLResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24JarURLResource$vtype _jc_java_net_URLClassLoader__24JarURLResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24JarURLResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24JarURLResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24JarURLResource_H_ */
